/* s2slides.h
 *
 * David Barnes, June 2007
 *
 * Based initially on glslides.h by Paul Bourke
 *
 * Distributed as part of the S2PLOT library
 *
 * ==================================================================
 * S2PLOT is freely available for non-commercial and educational use,
 * however, it is not public-domain software. The programming library
 * and documentation may not be redistributed or sub-licensed in any
 * form without permission from Swinburne University of
 * Technology. The programming library and sample codes are provided
 * without warranty.
 *
 * We would appreciate it if research outcomes using S2PLOT would
 * provide the following acknowledgement:
 *
 * "Three-dimensional visualisation was conducted with the S2PLOT
 * progamming library"
 *
 * and a reference to
 *
 * D.G.Barnes, C.J.Fluke, P.D.Bourke & O.T.Parry, 2006, Publications
 * of the Astronomical Society of Australia, 23(2), 82-93.
 *
 * S2PLOT development was funded through the Researcher Developer
 * Grant Scheme at Swinburne University of Technology.
 * ==================================================================
 *
 * $Id: s2slides.h,v 1.7 2008/03/14 03:07:49 dbarnes Exp dbarnes $
 *
 */

#if !defined(S2SLIDES_H)
#define S2SLIDES_H

#if defined(__cplusplus)
extern "C" {
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
//#include "vrglut.h"
#include "s2plot.h"
#include "s2glut.h"
#include <netdb.h>
#include <sys/time.h>
#include <sys/resource.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <unistd.h>
//#include "forms.h"
#include "paulslib.h"
#include "bitmaplib.h"
#include "opengllib.h"

#define NOSTEREO     0
#define ACTIVESTEREO 1
#define DUALSTEREO   2

#define PPM 0
#define RAW 1
#define TGA 2
#define RLE 3
#define TIF 4

typedef struct {
   char left[64];
   char right[64];
	int delay;
	int flip;
  int status; /* 0 = ready to read, 1 = bitmap loaded, 2 = texture created */
  int lw, lh, rw, rh; /* left and right image widths and heights */
  float laspect, raspect; /* left and right image aspect ratios */
  BITMAP4 *lbits, *rbits; /* left and right bitmaps */
  unsigned int ltex, rtex; /* left and right texture indices */
  char *command; /* command to execute, NULL if none */
} IMAGELIST;

  /* a structure to hold an image, its bitmap, and ultimately textureid */
  typedef struct {
    int status; /* 0 = ready to read, 1 = bitmap loaded, 2 = texture created */
    int w, h; /* image width & height */
    float aspect; /* image aspect ratio (width / height) */
    size_t size; /* byte count of image bitmap size */
    BITMAP4 *bits; /* image bitmap */
    unsigned int texid; /* texture id */
  } IMAGETEX;

typedef struct {
	int stereo;
	int fullscreen;
	int debug;
	int framedelay;                  // Time between frames 1/10 seconds
	int showhelp;	               
	int autoplay;                    // Run through slides automatically
	int exitsafe;                    // Require shift esc to end
	int exitatend;                   // Exit the show at the end
	int leftoffset,rightoffset;
	double xoffset,yoffset;
	double targetfps;
  int edit;
} OPTIONS;

void lGiveUsage(char *);
int  ReadImage(char *,int);
void ReadImagePair(void);
void HandleMemory(int,int,int);
void CreateDummy(int);

#if defined(__cplusplus)
} // extern "C" {
#endif

#endif
